summaryrefslogtreecommitdiffstats
path: root/kjsembed/builtins
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/builtins')
-rw-r--r--kjsembed/builtins/qdir_imp.cpp134
-rw-r--r--kjsembed/builtins/qdir_imp.h4
-rw-r--r--kjsembed/builtins/qfile_imp.cpp54
-rw-r--r--kjsembed/builtins/qfile_imp.h6
-rw-r--r--kjsembed/builtins/resources.cpp56
-rw-r--r--kjsembed/builtins/resources.h6
-rw-r--r--kjsembed/builtins/saxhandler.cpp28
-rw-r--r--kjsembed/builtins/saxhandler.h12
-rw-r--r--kjsembed/builtins/stdaction_imp.cpp6
-rw-r--r--kjsembed/builtins/stddialog_imp.cpp18
-rw-r--r--kjsembed/builtins/textstream_imp.cpp18
-rw-r--r--kjsembed/builtins/textstream_imp.h4
12 files changed, 173 insertions, 173 deletions
diff --git a/kjsembed/builtins/qdir_imp.cpp b/kjsembed/builtins/qdir_imp.cpp
index 32d79d14..55895a59 100644
--- a/kjsembed/builtins/qdir_imp.cpp
+++ b/kjsembed/builtins/qdir_imp.cpp
@@ -14,7 +14,7 @@
#include <kjsembed/jsopaqueproxy.h>
#include <kjsembed/jsbinding.h>
-#include <qdir.h>
+#include <tqdir.h>
#include "qdir_imp.h"
/**
@@ -26,10 +26,10 @@ namespace Bindings {
{
JSOpaqueProxy * prx;
if ( args.size() == 0 ) {
- prx = new JSOpaqueProxy( new QDir( QDir::current() ), "QDir" );
+ prx = new JSOpaqueProxy( new TQDir( TQDir::current() ), "TQDir" );
} else {
- QString arg0 = ( args.size() >= 1 ) ? args[ 0 ].toString( exec ).qstring() : QString::null;
- prx = new JSOpaqueProxy( new QDir( arg0 ), "QDir" );
+ TQString arg0 = ( args.size() >= 1 ) ? args[ 0 ].toString( exec ).qstring() : TQString::null;
+ prx = new JSOpaqueProxy( new TQDir( arg0 ), "TQDir" );
}
prx->setOwner( JSProxy::JavaScript );
KJS::Object proxyObj( prx );
@@ -177,31 +177,31 @@ void QDirImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
EnumValue enums[] = {
// enum FilterSpec
- { "Dirs", QDir::Dirs },
- { "Files", QDir::Files },
- { "Drives", QDir::Drives },
- { "NoSymLinks", QDir::NoSymLinks },
- { "All", QDir::All },
- { "TypeMask", QDir::TypeMask },
- { "Readable", QDir::Readable },
- { "Writable", QDir::Writable },
- { "Executable", QDir::Executable },
- { "RWEMask", QDir::RWEMask },
- { "Modified", QDir::Modified },
- { "Hidden", QDir::Hidden },
- { "System", QDir::System },
- { "AccessMask", QDir::AccessMask },
- { "DefaultFilter", QDir::DefaultFilter },
+ { "Dirs", TQDir::Dirs },
+ { "Files", TQDir::Files },
+ { "Drives", TQDir::Drives },
+ { "NoSymLinks", TQDir::NoSymLinks },
+ { "All", TQDir::All },
+ { "TypeMask", TQDir::TypeMask },
+ { "Readable", TQDir::Readable },
+ { "Writable", TQDir::Writable },
+ { "Executable", TQDir::Executable },
+ { "RWEMask", TQDir::RWEMask },
+ { "Modified", TQDir::Modified },
+ { "Hidden", TQDir::Hidden },
+ { "System", TQDir::System },
+ { "AccessMask", TQDir::AccessMask },
+ { "DefaultFilter", TQDir::DefaultFilter },
// enum SortSpec
- { "Name", QDir::Name },
- { "Time", QDir::Time },
- { "Size", QDir::Size },
- { "Unsorted", QDir::Unsorted },
- { "SortByMask", QDir::SortByMask },
- { "DirsFirst", QDir::DirsFirst },
- { "Reversed", QDir::Reversed },
- { "IgnoreCase", QDir::IgnoreCase },
- { "DefaultSort", QDir::DefaultSort },
+ { "Name", TQDir::Name },
+ { "Time", TQDir::Time },
+ { "Size", TQDir::Size },
+ { "Unsorted", TQDir::Unsorted },
+ { "SortByMask", TQDir::SortByMask },
+ { "DirsFirst", TQDir::DirsFirst },
+ { "Reversed", TQDir::Reversed },
+ { "IgnoreCase", TQDir::IgnoreCase },
+ { "DefaultSort", TQDir::DefaultSort },
{ 0, 0 }
};
@@ -222,12 +222,12 @@ KJS::Value QDirImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::Li
return KJS::Value();
}
- if ( op->typeName() != "QDir" ) {
+ if ( op->typeName() != "TQDir" ) {
kdWarning() << "QDirImp::call() failed, type is " << op->typeName() << endl;
return KJS::Value();
}
- instance = op->toNative<QDir>();
+ instance = op->toNative<TQDir>();
switch( mid ) {
@@ -431,7 +431,7 @@ KJS::Value QDirImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::Li
break;
}
- QString msg = i18n( "QDirImp has no method with id '%1'." ).arg( mid );
+ TQString msg = i18n( "QDirImp has no method with id '%1'." ).arg( mid );
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -439,7 +439,7 @@ KJS::Value QDirImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::Li
KJS::Value QDirImp::setPath_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : QString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
instance->setPath(
arg0 );
@@ -450,7 +450,7 @@ KJS::Value QDirImp::setPath_7( KJS::ExecState *exec, KJS::Object &obj, const KJS
KJS::Value QDirImp::path_8( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString ret;
+ TQString ret;
ret = instance->path( );
return KJS::String( ret );
@@ -459,7 +459,7 @@ KJS::Value QDirImp::path_8( KJS::ExecState *exec, KJS::Object &obj, const KJS::L
KJS::Value QDirImp::absPath_9( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString ret;
+ TQString ret;
ret = instance->absPath( );
return KJS::String( ret );
@@ -468,7 +468,7 @@ KJS::Value QDirImp::absPath_9( KJS::ExecState *exec, KJS::Object &obj, const KJS
KJS::Value QDirImp::canonicalPath_10( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString ret;
+ TQString ret;
ret = instance->canonicalPath( );
return KJS::String( ret );
@@ -477,7 +477,7 @@ KJS::Value QDirImp::canonicalPath_10( KJS::ExecState *exec, KJS::Object &obj, co
KJS::Value QDirImp::dirName_11( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString ret;
+ TQString ret;
ret = instance->dirName( );
return KJS::String( ret );
@@ -486,11 +486,11 @@ KJS::Value QDirImp::dirName_11( KJS::ExecState *exec, KJS::Object &obj, const KJ
KJS::Value QDirImp::filePath_12( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : QString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
bool arg1 = (args.size() >= 2) ? args[1].toBoolean(exec) : false;
- QString ret;
+ TQString ret;
ret = instance->filePath(
arg0,
arg1 );
@@ -501,11 +501,11 @@ KJS::Value QDirImp::filePath_12( KJS::ExecState *exec, KJS::Object &obj, const K
KJS::Value QDirImp::absFilePath_13( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : QString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
bool arg1 = (args.size() >= 2) ? args[1].toBoolean(exec) : false;
- QString ret;
+ TQString ret;
ret = instance->absFilePath(
arg0,
arg1 );
@@ -516,7 +516,7 @@ KJS::Value QDirImp::absFilePath_13( KJS::ExecState *exec, KJS::Object &obj, cons
KJS::Value QDirImp::cd_14( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : QString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
bool arg1 = (args.size() >= 2) ? args[1].toBoolean(exec) : false;
@@ -540,7 +540,7 @@ KJS::Value QDirImp::cdUp_15( KJS::ExecState *exec, KJS::Object &obj, const KJS::
KJS::Value QDirImp::nameFilter_16( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString ret;
+ TQString ret;
ret = instance->nameFilter( );
return KJS::String( ret );
@@ -549,7 +549,7 @@ KJS::Value QDirImp::nameFilter_16( KJS::ExecState *exec, KJS::Object &obj, const
KJS::Value QDirImp::setNameFilter_17( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : QString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
instance->setNameFilter(
arg0 );
@@ -641,7 +641,7 @@ KJS::Value QDirImp::encodedEntryList_26( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value QDirImp::encodedEntryList_27( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : QString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
int arg1 = (args.size() >= 2) ? args[1].toInteger(exec) : -1;
@@ -662,7 +662,7 @@ KJS::Value QDirImp::entryList_28( KJS::ExecState *exec, KJS::Object &obj, const
int arg1 = (args.size() >= 2) ? args[1].toInteger(exec) : -1;
- QStringList ret;
+ TQStringList ret;
ret = instance->entryList(
arg0,
arg1 );
@@ -674,13 +674,13 @@ KJS::Value QDirImp::entryList_28( KJS::ExecState *exec, KJS::Object &obj, const
KJS::Value QDirImp::entryList_29( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : QString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
int arg1 = (args.size() >= 2) ? args[1].toInteger(exec) : -1;
int arg2 = (args.size() >= 3) ? args[2].toInteger(exec) : -1;
- QStringList ret;
+ TQStringList ret;
ret = instance->entryList(
arg0,
arg1,
@@ -707,7 +707,7 @@ KJS::Value QDirImp::entryInfoList_30( KJS::ExecState *exec, KJS::Object &obj, co
KJS::Value QDirImp::entryInfoList_31( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : QString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
int arg1 = (args.size() >= 2) ? args[1].toInteger(exec) : -1;
@@ -724,7 +724,7 @@ KJS::Value QDirImp::entryInfoList_31( KJS::ExecState *exec, KJS::Object &obj, co
KJS::Value QDirImp::mkdir_32( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : QString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
bool arg1 = (args.size() >= 2) ? args[1].toBoolean(exec) : false;
@@ -739,7 +739,7 @@ KJS::Value QDirImp::mkdir_32( KJS::ExecState *exec, KJS::Object &obj, const KJS:
KJS::Value QDirImp::rmdir_33( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : QString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
bool arg1 = (args.size() >= 2) ? args[1].toBoolean(exec) : false;
@@ -798,7 +798,7 @@ KJS::Value QDirImp::convertToAbs_38( KJS::ExecState *exec, KJS::Object &obj, con
KJS::Value QDirImp::remove_41( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : QString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
bool arg1 = (args.size() >= 2) ? args[1].toBoolean(exec) : false;
@@ -813,9 +813,9 @@ KJS::Value QDirImp::remove_41( KJS::ExecState *exec, KJS::Object &obj, const KJS
KJS::Value QDirImp::rename_42( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : QString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
- QString arg1 = (args.size() >= 2) ? args[1].toString(exec).qstring() : QString::null;
+ TQString arg1 = (args.size() >= 2) ? args[1].toString(exec).qstring() : TQString::null;
bool arg2 = (args.size() >= 3) ? args[2].toBoolean(exec) : false;
@@ -831,7 +831,7 @@ KJS::Value QDirImp::rename_42( KJS::ExecState *exec, KJS::Object &obj, const KJS
KJS::Value QDirImp::exists_43( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : QString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
bool arg1 = (args.size() >= 2) ? args[1].toBoolean(exec) : false;
@@ -854,9 +854,9 @@ KJS::Value QDirImp::refresh_44( KJS::ExecState *exec, KJS::Object &obj, const KJ
KJS::Value QDirImp::convertSeparators_45( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : QString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
- QString ret;
+ TQString ret;
ret = instance->convertSeparators(
arg0 );
return KJS::String( ret );
@@ -882,7 +882,7 @@ KJS::Value QDirImp::separator_47( KJS::ExecState *exec, KJS::Object &obj, const
KJS::Value QDirImp::setCurrent_48( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : QString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
bool ret;
ret = instance->setCurrent(
@@ -918,7 +918,7 @@ KJS::Value QDirImp::root_51( KJS::ExecState *exec, KJS::Object &obj, const KJS::
KJS::Value QDirImp::currentDirPath_52( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString ret;
+ TQString ret;
ret = instance->currentDirPath( );
return KJS::String( ret );
@@ -927,7 +927,7 @@ KJS::Value QDirImp::currentDirPath_52( KJS::ExecState *exec, KJS::Object &obj, c
KJS::Value QDirImp::homeDirPath_53( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString ret;
+ TQString ret;
ret = instance->homeDirPath( );
return KJS::String( ret );
@@ -936,7 +936,7 @@ KJS::Value QDirImp::homeDirPath_53( KJS::ExecState *exec, KJS::Object &obj, cons
KJS::Value QDirImp::rootDirPath_54( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString ret;
+ TQString ret;
ret = instance->rootDirPath( );
return KJS::String( ret );
@@ -945,12 +945,12 @@ KJS::Value QDirImp::rootDirPath_54( KJS::ExecState *exec, KJS::Object &obj, cons
KJS::Value QDirImp::match_55( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QStringList arg0;
+ TQStringList arg0;
if ( args.size() >= 1 ) {
// TODO: populate the list
}
- QString arg1 = (args.size() >= 2) ? args[1].toString(exec).qstring() : QString::null;
+ TQString arg1 = (args.size() >= 2) ? args[1].toString(exec).qstring() : TQString::null;
bool ret;
ret = instance->match(
@@ -963,9 +963,9 @@ KJS::Value QDirImp::match_55( KJS::ExecState *exec, KJS::Object &obj, const KJS:
KJS::Value QDirImp::match_56( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : QString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
- QString arg1 = (args.size() >= 2) ? args[1].toString(exec).qstring() : QString::null;
+ TQString arg1 = (args.size() >= 2) ? args[1].toString(exec).qstring() : TQString::null;
bool ret;
ret = instance->match(
@@ -978,9 +978,9 @@ KJS::Value QDirImp::match_56( KJS::ExecState *exec, KJS::Object &obj, const KJS:
KJS::Value QDirImp::cleanDirPath_57( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : QString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
- QString ret;
+ TQString ret;
ret = instance->cleanDirPath(
arg0 );
return KJS::String( ret );
@@ -990,7 +990,7 @@ KJS::Value QDirImp::cleanDirPath_57( KJS::ExecState *exec, KJS::Object &obj, con
KJS::Value QDirImp::isRelativePath_58( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : QString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
bool ret;
ret = instance->isRelativePath(
diff --git a/kjsembed/builtins/qfile_imp.cpp b/kjsembed/builtins/qfile_imp.cpp
index d404e239..abc38d09 100644
--- a/kjsembed/builtins/qfile_imp.cpp
+++ b/kjsembed/builtins/qfile_imp.cpp
@@ -1,9 +1,9 @@
-#include <qcstring.h>
-#include <qpalette.h>
-#include <qpixmap.h>
-#include <qfont.h>
+#include <tqcstring.h>
+#include <tqpalette.h>
+#include <tqpixmap.h>
+#include <tqfont.h>
#ifndef QT_ONLY
#include <klocale.h>
@@ -17,7 +17,7 @@
#include <kjsembed/jsbinding.h>
#include <kjsembed/global.h>
-#include <qfile.h>
+#include <tqfile.h>
#include "qfile_imp.h"
/**
@@ -71,7 +71,7 @@ void QFileImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
};
int idx = 0;
- QCString lastName;
+ TQCString lastName;
do {
if ( lastName != methods[idx].name ) {
@@ -85,23 +85,23 @@ void QFileImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
-QFile *QFileImp::toQFile( KJS::Object &self )
+TQFile *QFileImp::toQFile( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- QObject *obj = ob->object();
+ TQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<QFile *>( obj );
+ return dynamic_cast<TQFile *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
if ( !op )
return 0;
- if ( op->typeName() != "QFile" )
+ if ( op->typeName() != "TQFile" )
return 0;
- return op->toNative<QFile>();
+ return op->toNative<TQFile>();
}
@@ -121,7 +121,7 @@ KJS::Object QFileImp::construct( KJS::ExecState *exec, const KJS::List &args )
break;
}
- QString msg = i18n("QFileCons has no constructor with id '%1'.").arg(id);
+ TQString msg = i18n("QFileCons has no constructor with id '%1'.").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -135,7 +135,7 @@ KJS::Object QFileImp::QFile_2( KJS::ExecState *exec, const KJS::List &args )
{
// TODO
- QWidget *arg0 = 0L;
+ TQWidget *arg0 = 0L;
return KJS::Object();
}
@@ -266,7 +266,7 @@ KJS::Value QFileImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::L
break;
}
- QString msg = i18n( "QFileImp has no method with id '%1'." ).arg( id );
+ TQString msg = i18n( "QFileImp has no method with id '%1'." ).arg( id );
return throwError(exec, msg, KJS::ReferenceError );
}
@@ -274,7 +274,7 @@ KJS::Value QFileImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::L
KJS::Value QFileImp::name_4( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString ret;
+ TQString ret;
ret = instance->name( );
return KJS::String( ret );
@@ -283,7 +283,7 @@ KJS::Value QFileImp::name_4( KJS::ExecState *exec, KJS::Object &obj, const KJS::
KJS::Value QFileImp::setName_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : QString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
instance->setName(
arg0 );
@@ -389,7 +389,7 @@ KJS::Value QFileImp::at_14( KJS::ExecState *exec, KJS::Object &obj, const KJS::L
KJS::Value QFileImp::at_15( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QFile::Offset arg0 = 0; // TODO (hack for qfile)
+ TQFile::Offset arg0 = 0; // TODO (hack for qfile)
bool ret;
ret = instance->at(
@@ -447,7 +447,7 @@ KJS::Value QFileImp::writeBlock_18( KJS::ExecState *exec, KJS::Object &obj, cons
KJS::Value QFileImp::writeBlock_19( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QByteArray arg0; // TODO (hack for qfile)
+ TQByteArray arg0; // TODO (hack for qfile)
instance->writeBlock(
arg0 );
@@ -478,7 +478,7 @@ KJS::Value QFileImp::readLine_20( KJS::ExecState *exec, KJS::Object &obj, const
KJS::Value QFileImp::readLine_21( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : QString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
// Unsupported parameter Q_ULONG
return KJS::Value();
@@ -537,7 +537,7 @@ KJS::Value QFileImp::handle_25( KJS::ExecState *exec, KJS::Object &obj, const KJ
KJS::Value QFileImp::errorString_26( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString ret;
+ TQString ret;
ret = instance->errorString( );
return KJS::String( ret );
@@ -546,7 +546,7 @@ KJS::Value QFileImp::errorString_26( KJS::ExecState *exec, KJS::Object &obj, con
KJS::Value QFileImp::encodeName_27( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : QString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
instance->encodeName(
arg0 );
@@ -557,9 +557,9 @@ KJS::Value QFileImp::encodeName_27( KJS::ExecState *exec, KJS::Object &obj, cons
KJS::Value QFileImp::decodeName_28( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- const QCString arg0 = (args.size() >= 1) ? args[0].toString(exec).ascii() : 0;
+ const TQCString arg0 = (args.size() >= 1) ? args[0].toString(exec).ascii() : 0;
- QString ret;
+ TQString ret;
ret = instance->decodeName(
arg0 );
return KJS::String( ret );
@@ -569,7 +569,7 @@ KJS::Value QFileImp::decodeName_28( KJS::ExecState *exec, KJS::Object &obj, cons
KJS::Value QFileImp::setEncodingFunction_29( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QFile::EncoderFn arg0 = 0; // TODO (hack for qfile)
+ TQFile::EncoderFn arg0 = 0; // TODO (hack for qfile)
instance->setEncodingFunction(
arg0 );
@@ -580,7 +580,7 @@ KJS::Value QFileImp::setEncodingFunction_29( KJS::ExecState *exec, KJS::Object &
KJS::Value QFileImp::setDecodingFunction_30( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QFile::DecoderFn arg0 = 0; // TODO (hack for qfile)
+ TQFile::DecoderFn arg0 = 0; // TODO (hack for qfile)
instance->setDecodingFunction(
arg0 );
@@ -591,7 +591,7 @@ KJS::Value QFileImp::setDecodingFunction_30( KJS::ExecState *exec, KJS::Object &
KJS::Value QFileImp::exists_31( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : QString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
bool ret;
ret = instance->exists(
@@ -603,7 +603,7 @@ KJS::Value QFileImp::exists_31( KJS::ExecState *exec, KJS::Object &obj, const KJ
KJS::Value QFileImp::remove_32( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : QString::null;
+ TQString arg0 = (args.size() >= 1) ? args[0].toString(exec).qstring() : TQString::null;
bool ret;
ret = instance->remove(
diff --git a/kjsembed/builtins/resources.cpp b/kjsembed/builtins/resources.cpp
index 14912303..84128f69 100644
--- a/kjsembed/builtins/resources.cpp
+++ b/kjsembed/builtins/resources.cpp
@@ -24,8 +24,8 @@
#include <jsproxy.h>
#include <jsbinding.h>
#include <jsfactory.h>
-#include <qdir.h>
-#include <qapplication.h>
+#include <tqdir.h>
+#include <tqapplication.h>
#include "resources.h"
namespace KJSEmbed {
@@ -70,75 +70,75 @@ void StdDirsImp::addBindings( KJS::ExecState *exec, KJS::Object &parent )
KJS::Value StdDirsImp::call( KJS::ExecState *exec, KJS::Object &/*self*/, const KJS::List &args )
{
-// QString arg0 = extractQString(exec, args, 0);
-// QString arg1 = extractQString(exec, args, 1);
+// TQString arg0 = extractQString(exec, args, 0);
+// TQString arg1 = extractQString(exec, args, 1);
switch( id ) {
case StdDirsImp::findResource:
{
- QString arg0 = extractQString(exec, args, 0);
- QString arg1 = extractQString(exec, args, 1);
- QString path = KGlobal::dirs ()->findResource(arg0.latin1(), arg1);
+ TQString arg0 = extractQString(exec, args, 0);
+ TQString arg1 = extractQString(exec, args, 1);
+ TQString path = KGlobal::dirs ()->findResource(arg0.latin1(), arg1);
return KJS::String( path );
}
case StdDirsImp::addResourceType:
{
- QString arg0 = extractQString(exec, args, 0);
- QString arg1 = extractQString(exec, args, 1);
+ TQString arg0 = extractQString(exec, args, 0);
+ TQString arg1 = extractQString(exec, args, 1);
bool isOk = KGlobal::dirs ()->addResourceType(arg0.latin1(), arg1);
return KJS::Boolean( isOk );
}
case StdDirsImp::kde_default:
{
- QString arg0 = extractQString(exec, args, 0);
- QString path = KGlobal::dirs ()->kde_default(arg0.latin1());
+ TQString arg0 = extractQString(exec, args, 0);
+ TQString path = KGlobal::dirs ()->kde_default(arg0.latin1());
return KJS::String( path );
}
case StdDirsImp::addResourceDir:
{
- QString arg0 = extractQString(exec, args, 0);
- QString arg1 = extractQString(exec, args, 1);
+ TQString arg0 = extractQString(exec, args, 0);
+ TQString arg1 = extractQString(exec, args, 1);
bool isOk = KGlobal::dirs ()->addResourceDir(arg0.latin1(), arg1);
return KJS::Boolean( isOk );
}
case StdDirsImp::findResourceDir:
{
- QString arg0 = extractQString(exec, args, 0);
- QString arg1 = extractQString(exec, args, 1);
- QString path = KGlobal::dirs ()->findResourceDir(arg0.latin1(), arg1);
+ TQString arg0 = extractQString(exec, args, 0);
+ TQString arg1 = extractQString(exec, args, 1);
+ TQString path = KGlobal::dirs ()->findResourceDir(arg0.latin1(), arg1);
return KJS::String( path );
}
case StdDirsImp::saveLocation:
{
- QString arg0 = extractQString(exec, args, 0);
- QString arg1 = extractQString(exec, args, 1);
+ TQString arg0 = extractQString(exec, args, 0);
+ TQString arg1 = extractQString(exec, args, 1);
bool arg2 = (args.size() > 2) ? args[2].toBoolean(exec) : true;
- QString path = KGlobal::dirs ()->saveLocation(arg0.latin1(), arg1, arg2);
+ TQString path = KGlobal::dirs ()->saveLocation(arg0.latin1(), arg1, arg2);
return KJS::String( path );
}
case StdDirsImp::makeDir:
{
- QString arg0 = extractQString(exec, args, 0);
+ TQString arg0 = extractQString(exec, args, 0);
int arg1 = (args.size() > 1) ? args[1].toInteger(exec) : 0755;
bool isOk = KStandardDirs::makeDir(arg0, arg1);
return KJS::Boolean( isOk );
}
case StdDirsImp::exists:
{
- QString arg0 = extractQString(exec, args, 0);
+ TQString arg0 = extractQString(exec, args, 0);
bool isOk = KStandardDirs::exists(arg0);
return KJS::Boolean( isOk );
}
case StdDirsImp::realPath:
{
- QString arg0 = extractQString(exec, args, 0);
- QString path = KStandardDirs::realPath(arg0);
+ TQString arg0 = extractQString(exec, args, 0);
+ TQString path = KStandardDirs::realPath(arg0);
return KJS::String( path );
}
case StdDirsImp::currentDirPath:
- return KJS::String(QDir::currentDirPath());
+ return KJS::String(TQDir::currentDirPath());
case StdDirsImp::homeDirPath:
- return KJS::String(QDir::homeDirPath());
+ return KJS::String(TQDir::homeDirPath());
case StdDirsImp::applicationDirPath:
return KJS::String(qApp->applicationDirPath());
default:
@@ -178,14 +178,14 @@ void StdIconsImp::addBindings( JSFactory *fact, KJS::ExecState *exec, KJS::Obje
}
-KJS::Value StdIconsImp::wrapPixmap(KJS::ExecState *exec, const QPixmap &icon)
+KJS::Value StdIconsImp::wrapPixmap(KJS::ExecState *exec, const TQPixmap &icon)
{
return convertToValue(exec, icon);
}
KJS::Value StdIconsImp::call( KJS::ExecState *exec, KJS::Object &/*obj*/, const KJS::List &args )
{
- QString arg0 = extractQString(exec, args, 0); // Name
+ TQString arg0 = extractQString(exec, args, 0); // Name
int arg1 = extractInt(exec, args, 1); // Size 0, 16, 24, 32, 48, 64, 128
int arg2 = extractInt(exec, args, 2);
// State 0 DefaultState, 1 ActiveState, 2 DisabledState, 3 LastState
@@ -212,7 +212,7 @@ KJS::Value StdIconsImp::call( KJS::ExecState *exec, KJS::Object &/*obj*/, const
}
case StdIconsImp::MimeSourceIcon:
{
- return wrapPixmap( exec, QPixmap::fromMimeSource(arg0));
+ return wrapPixmap( exec, TQPixmap::fromMimeSource(arg0));
}
default:
kdWarning() << "StdDirsImp has no method " << id << endl;
diff --git a/kjsembed/builtins/resources.h b/kjsembed/builtins/resources.h
index d83cd0b3..cfd589ce 100644
--- a/kjsembed/builtins/resources.h
+++ b/kjsembed/builtins/resources.h
@@ -22,7 +22,7 @@
#ifndef KJSEMBED_RESOURCES_H
#define KJSEMBED_RESOURCES_H
-#include <qpixmap.h>
+#include <tqpixmap.h>
#include <kjs/interpreter.h>
#include <kjs/object.h>
@@ -87,8 +87,8 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- /** wrap a QPixmap **/
- KJS::Value wrapPixmap(KJS::ExecState *exec,const QPixmap &icon);
+ /** wrap a TQPixmap **/
+ KJS::Value wrapPixmap(KJS::ExecState *exec,const TQPixmap &icon);
uint id;
JSFactory *jsfact;
};
diff --git a/kjsembed/builtins/saxhandler.cpp b/kjsembed/builtins/saxhandler.cpp
index d4a6f5f3..ff0334bf 100644
--- a/kjsembed/builtins/saxhandler.cpp
+++ b/kjsembed/builtins/saxhandler.cpp
@@ -23,7 +23,7 @@ namespace KJSEmbed {
namespace BuiltIns {
SaxHandler::SaxHandler( KJS::ExecState *execstate )
- : QXmlDefaultHandler(), exec(execstate), error( ErrorNone )
+ : TQXmlDefaultHandler(), exec(execstate), error( ErrorNone )
{
}
@@ -45,7 +45,7 @@ bool SaxHandler::startDocument()
KJS::Identifier funName("startDocument");
if ( !jshandler.hasProperty(exec, funName) )
- return QXmlDefaultHandler::startDocument();
+ return TQXmlDefaultHandler::startDocument();
KJS::Object fun = jshandler.get(exec, funName).toObject( exec );
if ( !fun.implementsCall() ) {
@@ -66,7 +66,7 @@ bool SaxHandler::endDocument()
KJS::Identifier funName("endDocument");
if ( !jshandler.hasProperty(exec, funName) )
- return QXmlDefaultHandler::endDocument();
+ return TQXmlDefaultHandler::endDocument();
KJS::Object fun = jshandler.get(exec, funName).toObject( exec );
if ( !fun.implementsCall() ) {
@@ -78,8 +78,8 @@ bool SaxHandler::endDocument()
return ret.toBoolean( exec );
}
-bool SaxHandler::startElement( const QString &ns, const QString &ln, const QString &qn,
- const QXmlAttributes &attrs )
+bool SaxHandler::startElement( const TQString &ns, const TQString &ln, const TQString &qn,
+ const TQXmlAttributes &attrs )
{
if ( !jshandler.isValid() ) {
error = ErrorNoHandler;
@@ -88,7 +88,7 @@ bool SaxHandler::startElement( const QString &ns, const QString &ln, const QStri
KJS::Identifier funName("startElement");
if ( !jshandler.hasProperty(exec, funName) )
- return QXmlDefaultHandler::startElement( ns, ln, qn, attrs );
+ return TQXmlDefaultHandler::startElement( ns, ln, qn, attrs );
KJS::Object fun = jshandler.get(exec, funName).toObject( exec );
if ( !fun.implementsCall() ) {
@@ -106,7 +106,7 @@ bool SaxHandler::startElement( const QString &ns, const QString &ln, const QStri
return ret.toBoolean( exec );
}
-bool SaxHandler::endElement( const QString &ns, const QString &ln, const QString &qn )
+bool SaxHandler::endElement( const TQString &ns, const TQString &ln, const TQString &qn )
{
if ( !jshandler.isValid() ) {
error = ErrorNoHandler;
@@ -115,7 +115,7 @@ bool SaxHandler::endElement( const QString &ns, const QString &ln, const QString
KJS::Identifier funName("endElement");
if ( !jshandler.hasProperty(exec, funName) )
- return QXmlDefaultHandler::endElement( ns, ln, qn );
+ return TQXmlDefaultHandler::endElement( ns, ln, qn );
KJS::Object fun = jshandler.get(exec, funName).toObject( exec );
if ( !fun.implementsCall() ) {
@@ -132,7 +132,7 @@ bool SaxHandler::endElement( const QString &ns, const QString &ln, const QString
return ret.toBoolean( exec );
}
-bool SaxHandler::characters( const QString &chars )
+bool SaxHandler::characters( const TQString &chars )
{
if ( !jshandler.isValid() ) {
error = ErrorNoHandler;
@@ -141,7 +141,7 @@ bool SaxHandler::characters( const QString &chars )
KJS::Identifier funName("characters");
if ( !jshandler.hasProperty(exec, funName) )
- return QXmlDefaultHandler::characters( chars );
+ return TQXmlDefaultHandler::characters( chars );
KJS::Object fun = jshandler.get(exec, funName).toObject( exec );
if ( !fun.implementsCall() ) {
@@ -156,15 +156,15 @@ bool SaxHandler::characters( const QString &chars )
return ret.toBoolean( exec );
}
-QString SaxHandler::errorString()
+TQString SaxHandler::errorString()
{
switch( error ) {
case ErrorNoHandler:
- return QString("No handler specified");
+ return TQString("No handler specified");
break;
case ErrorNotCallable:
- return QString("One of the callbacks of the handler is not callable");
+ return TQString("One of the callbacks of the handler is not callable");
break;
case ErrorNone:
// This only means that no error occured in the JS dispatch, there
@@ -175,7 +175,7 @@ QString SaxHandler::errorString()
break;
}
- return QXmlDefaultHandler::errorString();
+ return TQXmlDefaultHandler::errorString();
}
} // namespace KJSEmbed::BuiltIns
diff --git a/kjsembed/builtins/saxhandler.h b/kjsembed/builtins/saxhandler.h
index f396dbfe..fbf3e512 100644
--- a/kjsembed/builtins/saxhandler.h
+++ b/kjsembed/builtins/saxhandler.h
@@ -22,7 +22,7 @@
#ifndef KJSEMBED_SAXHANDLER_H
#define KJSEMBED_SAXHANDLER_H
-#include <qxml.h>
+#include <tqxml.h>
#include <kjs/object.h>
namespace KJSEmbed {
@@ -57,12 +57,12 @@ public:
virtual bool startDocument();
virtual bool endDocument();
- virtual bool startElement( const QString &ns, const QString &ln, const QString &qn,
- const QXmlAttributes &attrs );
- virtual bool endElement( const QString &ns, const QString &ln, const QString &qn );
- virtual bool characters( const QString &chars );
+ virtual bool startElement( const TQString &ns, const TQString &ln, const TQString &qn,
+ const TQXmlAttributes &attrs );
+ virtual bool endElement( const TQString &ns, const TQString &ln, const TQString &qn );
+ virtual bool characters( const TQString &chars );
- virtual QString errorString();
+ virtual TQString errorString();
private:
KJS::ExecState *exec;
diff --git a/kjsembed/builtins/stdaction_imp.cpp b/kjsembed/builtins/stdaction_imp.cpp
index 1361acf8..cad81bfe 100644
--- a/kjsembed/builtins/stdaction_imp.cpp
+++ b/kjsembed/builtins/stdaction_imp.cpp
@@ -75,12 +75,12 @@ KJS::Value StdActionImp::call( KJS::ExecState *exec, KJS::Object &/*self*/, cons
return KJS::Null();
// recv, slot, parent, name?
- QObject *recv = extractQObject( exec, args, 0);
+ TQObject *recv = extractQObject( exec, args, 0);
- QString sl = extractQString( exec, args, 1 );
+ TQString sl = extractQString( exec, args, 1 );
const char *slc = sl.isNull() ? "" : sl.ascii();
- QObject *parentobj = extractQObject( exec, args, 2 );
+ TQObject *parentobj = extractQObject( exec, args, 2 );
KActionCollection *parent = parentobj ? dynamic_cast<KActionCollection *>( parentobj ) : 0;
KStdAction::StdAction actid = static_cast<KStdAction::StdAction>(id);
diff --git a/kjsembed/builtins/stddialog_imp.cpp b/kjsembed/builtins/stddialog_imp.cpp
index 1b45c5e0..48bb468d 100644
--- a/kjsembed/builtins/stddialog_imp.cpp
+++ b/kjsembed/builtins/stddialog_imp.cpp
@@ -25,7 +25,7 @@
#else
-#include <qfiledialog.h>
+#include <tqfiledialog.h>
#define KFileDialog QFileDialog
#endif // QT_ONLY
@@ -76,32 +76,32 @@ void StdDialogImp::addBindings( KJS::ExecState *exec, KJS::Object &parent )
KJS::Value StdDialogImp::call( KJS::ExecState *exec, KJS::Object &/*self*/, const KJS::List &args )
{
- QString arg0 = (args.size() > 0) ? args[0].toString(exec).qstring() : QString::null;
- QString arg1 = (args.size() > 1) ? args[1].toString(exec).qstring() : QString::null;
+ TQString arg0 = (args.size() > 0) ? args[0].toString(exec).qstring() : TQString::null;
+ TQString arg1 = (args.size() > 1) ? args[1].toString(exec).qstring() : TQString::null;
switch( id ) {
case MethodGetOpenFileName:
{
- QString s = KFileDialog::getOpenFileName( arg0, arg1 );
+ TQString s = KFileDialog::getOpenFileName( arg0, arg1 );
return KJS::String( s );
}
case MethodGetSaveFileName:
{
- QString s = KFileDialog::getSaveFileName( arg0, arg1 );
+ TQString s = KFileDialog::getSaveFileName( arg0, arg1 );
return KJS::String( s );
}
case MethodGetExistingDirectory:
{
- QString s = KFileDialog::getExistingDirectory( arg0 );
+ TQString s = KFileDialog::getExistingDirectory( arg0 );
return KJS::String( s );
}
#ifndef QT_ONLY
case MethodGetColor:
{
- QColor col;
+ TQColor col;
int res = KColorDialog::getColor( col );
- if ( res == QDialog::Accepted )
- return convertToValue( exec, QVariant(col) );
+ if ( res == TQDialog::Accepted )
+ return convertToValue( exec, TQVariant(col) );
}
case MethodGetOpenURL:
{
diff --git a/kjsembed/builtins/textstream_imp.cpp b/kjsembed/builtins/textstream_imp.cpp
index 6be24dd9..4ab3aeb1 100644
--- a/kjsembed/builtins/textstream_imp.cpp
+++ b/kjsembed/builtins/textstream_imp.cpp
@@ -17,8 +17,8 @@
* Boston, MA 02110-1301, USA.
*/
-#include <qtextstream.h>
-#include <qiodevice.h>
+#include <tqtextstream.h>
+#include <tqiodevice.h>
#include <kjsembed/global.h>
#include <kjsembed/jsbinding.h>
@@ -28,7 +28,7 @@
namespace KJSEmbed {
namespace BuiltIns {
-TextStreamImp::TextStreamImp( KJS::ExecState *exec, int mid, QTextStream *textstream )
+TextStreamImp::TextStreamImp( KJS::ExecState *exec, int mid, TQTextStream *textstream )
: JSProxyImp(exec), id(mid), ts(textstream)
{
}
@@ -47,7 +47,7 @@ void TextStreamImp::addBindings( KJS::ExecState *exec, KJS::Object &parent )
return;
}
- QTextStream *ts = op->toTextStream();
+ TQTextStream *ts = op->toTextStream();
if ( !ts ) {
kdWarning() << "TextStreamImp::addBindings() failed, type is " << op->typeName() << endl;
return;
@@ -73,12 +73,12 @@ void TextStreamImp::addBindings( KJS::ExecState *exec, KJS::Object &parent )
KJS::Value TextStreamImp::call( KJS::ExecState *exec, KJS::Object &/*self*/, const KJS::List &args )
{
- QString not_readable = i18n( "Attempt to read from a write-only text stream." );
- QString not_writable = i18n( "Attempt to write to a read-only text stream." );
+ TQString not_readable = i18n( "Attempt to read from a write-only text stream." );
+ TQString not_writable = i18n( "Attempt to write to a read-only text stream." );
- QString arg0 = extractQString(exec, args, 0);
+ TQString arg0 = extractQString(exec, args, 0);
- QIODevice *dev = ts->device();
+ TQIODevice *dev = ts->device();
KJS::Object err;
switch ( id ) {
@@ -102,7 +102,7 @@ KJS::Value TextStreamImp::call( KJS::ExecState *exec, KJS::Object &/*self*/, con
break;
case MethodReadLine:
if ( dev->isReadable() ) {
- QString line = ts->readLine();
+ TQString line = ts->readLine();
if ( line.isNull() )
return KJS::Null();
else
diff --git a/kjsembed/builtins/textstream_imp.h b/kjsembed/builtins/textstream_imp.h
index ca46fc37..055cbe9d 100644
--- a/kjsembed/builtins/textstream_imp.h
+++ b/kjsembed/builtins/textstream_imp.h
@@ -51,7 +51,7 @@ public:
MethodFlush
};
- TextStreamImp( KJS::ExecState *exec, int id, QTextStream *ts );
+ TextStreamImp( KJS::ExecState *exec, int id, TQTextStream *ts );
~TextStreamImp();
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
@@ -64,7 +64,7 @@ public:
private:
int id;
- QTextStream *ts;
+ TQTextStream *ts;
class TextStreamImpPrivate *d;
};
diff --git a/kjsembed/builtins/qdir_imp.h b/kjsembed/builtins/qdir_imp.h
index f78850e7..7a8aa86b 100644
--- a/kjsembed/builtins/qdir_imp.h
+++ b/kjsembed/builtins/qdir_imp.h
@@ -25,7 +25,7 @@ namespace Bindings {
};
}
/**
* Wrapper class for QDir methods.
*
* @author Richard Moore, rich@kde.org
*/
@@ -157,7 +157,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- QDir *instance; // Temp
+ TQDir *instance; // Temp
int mid;
};
@@ -25,7 +25,7 @@ namespace Bindings {
}
/**
- * Wrapper class for QDir methods.
+ * Wrapper class for TQDir methods.
*
* @author Richard Moore, rich@kde.org
diff --git a/kjsembed/builtins/qfile_imp.h b/kjsembed/builtins/qfile_imp.h
index ae88dd52..d116040e 100644
--- a/kjsembed/builtins/qfile_imp.h
+++ b/kjsembed/builtins/qfile_imp.h
@@ -17,7 +17,7 @@ class QFile;
namespace KJSEmbed {
/**
* Wrapper class for QFile methods.
*
* @author Richard Moore, rich@kde.org
*/
@@ -72,7 +72,7 @@ public:
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
- static QFile *toQFile( KJS::Object &object );
+ static TQFile *toQFile( KJS::Object &object );
//
// Constructors implemented by this class.
@@ -132,7 +132,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- QFile *instance; // Temp
+ TQFile *instance; // Temp
int id;
bool cons;
};
@@ -17,7 +17,7 @@ class QFile;
namespace KJSEmbed {
/**
- * Wrapper class for QFile methods.
+ * Wrapper class for TQFile methods.
*
* @author Richard Moore, rich@kde.org